@@ -1,6 +1,7 @@
 import argparse
 
 from irco.explorer import app, database, filters
+from irco.logging import sentry
 
 
 def main():
@@ -12,6 +13,11 @@ def main():
 
     args = argparser.parse_args()
 
+    sentry.context.merge({
+        'tags': {'command': 'irco-explorer'},
+        'extra': {'parsed_arguments': args.__dict__}
+    })
+
     app.config['DATABASE'] = args.database
     database.init_app(app)
     filters.init_app(app)
